@@ -2,9 +2,11 @@
 #include <Rdefines.h>
 #include "NScluster.h"
 
-extern void F77_NAME(palmcf)(double*, double*, int*, double*, double*, double*, double*, double*, double*, double*, int*, int*, double*, double*);
+extern void F77_NAME(palmcf)(double*, double*, int*, double*, double*, double*,
+                             double*, double*, double*, double*, int*, int*, double*, double*);
 
-SEXP palmC(SEXP x, SEXP y, SEXP np, SEXP delta, SEXP ty, SEXP alam, SEXP anu1, SEXP a, SEXP s1, SEXP s2, SEXP m, SEXP jmax)
+SEXP palmC(SEXP x, SEXP y, SEXP np, SEXP delta, SEXP ty, SEXP alam, SEXP anu1,
+           SEXP a, SEXP s1, SEXP s2, SEXP m, SEXP jmax)
 {
     double *d1,*d2,*d3,*d4,*d5,*d6,*d7,*d8,*d9,*d10,*d11;
     int *i1,*i2,*i3;
